Setting up Shopyo — Shopyo documentation

# Setting up Shopyo

Shopyo requires Python. Be sure to have it before!

## 👟 The easy way

- [Important] create a virtual environment and activate it.

- install shopyo

    pip install shopyo

- create new project

- create new shopyo project

    shopyo new /path/to/location project-name

example

    shopyo new /home/profiles/arj/desktop shopyotest

- cd into path. if you added path as `.` just cd into `project-name`

- initialise

    shopyo initialise

- run

    shopyo runserver

Note

If the shopyo command is not recognized. close your commandline prompt and reopen

## 🔧 Install from Github

- clone and cd into shopyo/shopyo

    git clone https://github.com/Abdur-rahmaanJ/shopyo
    cd shopyo/shopyo

- install requirements

    python -m pip install -r requirements.txt

or if you want to contribute

    python -m pip install -r dev_requirements.txt

`cd` into shopyo/shopyo if not done already.

initialise and setup app.

    python manage.py createconfig
    python manage.py initialise

run the app.

    python manage.py runserver

go to the indicated url

## Default Login

    email: admin@domain.com
    password: pass